@@ -41,10 +41,11 @@ class FileApp(object):
 
 class DirectoryServer(object):
 
-    def __init__(self, directory):
+    def __init__(self, directory, sort=True):
         assert os.path.exists(directory), "'%s' does not exist" % directory
         assert os.path.isdir(directory), "'%s' is not a directory" % directory
         self.directory = self.normpath(directory)
+        self.sort = sort
 
     @staticmethod
     def normpath(path):
@@ -65,6 +66,8 @@ class DirectoryServer(object):
         """
         parts = ['<html><head><title>Simple Index</title></head><body>']
         listings = os.listdir(directory)
+        if self.sort:
+            listings.sort()
         listings = [(os.path.isdir(os.path.join(directory, entry)) and entry + '/' or entry, entry)
                     for entry in listings]
         for link, entry in listings:
